@@ -41,8 +41,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     FilterTypeDef,
@@ -85,7 +84,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListDeploymentJobsPaginator(Boto3Paginator):
+class ListDeploymentJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listdeploymentjobspaginator)
@@ -103,7 +102,7 @@ class ListDeploymentJobsPaginator(Boto3Paginator):
         """
 
 
-class ListFleetsPaginator(Boto3Paginator):
+class ListFleetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listfleetspaginator)
@@ -121,7 +120,7 @@ class ListFleetsPaginator(Boto3Paginator):
         """
 
 
-class ListRobotApplicationsPaginator(Boto3Paginator):
+class ListRobotApplicationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listrobotapplicationspaginator)
@@ -140,7 +139,7 @@ class ListRobotApplicationsPaginator(Boto3Paginator):
         """
 
 
-class ListRobotsPaginator(Boto3Paginator):
+class ListRobotsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listrobotspaginator)
@@ -158,7 +157,7 @@ class ListRobotsPaginator(Boto3Paginator):
         """
 
 
-class ListSimulationApplicationsPaginator(Boto3Paginator):
+class ListSimulationApplicationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listsimulationapplicationspaginator)
@@ -177,7 +176,7 @@ class ListSimulationApplicationsPaginator(Boto3Paginator):
         """
 
 
-class ListSimulationJobBatchesPaginator(Boto3Paginator):
+class ListSimulationJobBatchesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listsimulationjobbatchespaginator)
@@ -195,7 +194,7 @@ class ListSimulationJobBatchesPaginator(Boto3Paginator):
         """
 
 
-class ListSimulationJobsPaginator(Boto3Paginator):
+class ListSimulationJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listsimulationjobspaginator)
@@ -213,7 +212,7 @@ class ListSimulationJobsPaginator(Boto3Paginator):
         """
 
 
-class ListWorldExportJobsPaginator(Boto3Paginator):
+class ListWorldExportJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldExportJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listworldexportjobspaginator)
@@ -231,7 +230,7 @@ class ListWorldExportJobsPaginator(Boto3Paginator):
         """
 
 
-class ListWorldGenerationJobsPaginator(Boto3Paginator):
+class ListWorldGenerationJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldGenerationJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listworldgenerationjobspaginator)
@@ -249,7 +248,7 @@ class ListWorldGenerationJobsPaginator(Boto3Paginator):
         """
 
 
-class ListWorldTemplatesPaginator(Boto3Paginator):
+class ListWorldTemplatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListWorldTemplates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listworldtemplatespaginator)
@@ -264,7 +263,7 @@ class ListWorldTemplatesPaginator(Boto3Paginator):
         """
 
 
-class ListWorldsPaginator(Boto3Paginator):
+class ListWorldsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/robomaker.html#RoboMaker.Paginator.ListWorlds)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/paginators/#listworldspaginator)
